<?php

defined('ABSPATH') || exit;

require_once plugin_dir_path(dirname(__FILE__)) . 'api/class-woo-lithuaniapost-admin-api.php';

enum ShippingStatus
{
    case IN_PROGRESS;
    case SUCCESSFUL;
    case PARTIALLY_SUCCESSFUL;
    case ERROR;

    public static function is_status_ok(string $status): bool
    {
        return $status == ShippingStatus::SUCCESSFUL->name || $status == ShippingStatus::PARTIALLY_SUCCESSFUL->name;
    }
}

enum ShippingItemStatus
{
    case OK;
    case FAILED;
    case COURIER_PENDING;
    case COURIER_CALLED;

    public static function is_status_ok(string $status):bool{
        return $status == ShippingItemStatus::OK->name || $status == ShippingItemStatus::COURIER_PENDING->name || $status == ShippingItemStatus::COURIER_CALLED->name;
    }
}

/**
 * The admin-specific api hooks functionality of the plugin.
 *
 * @package    Woo_Lithuaniapost
 * @subpackage Woo_Lithuaniapost/admin
 * @author     AB "Lietuvos Paštas" <info@post.lt>
 */
class Woo_Lithuaniapost_Admin_Shipping_Api extends Woo_Lithuaniapost_Admin_Api
{
    public function __construct($plugin_name, $version)
    {
        parent::__construct($plugin_name, $version);
    }

    /**
     * Authentication gateways
     */
    const INITIATE_URI = 'shipping/initiate?processAsync=false';
    const STATUS_URI = 'shipping/status/';
    const CANCEL_URI = 'shipping/cancel';
    const AVAILABLE_URI = 'shipping/available';

    function initiate(array $order_ids): bool|stdClass
    {
        $body["idRefs"] = $order_ids;
        $initiate_result = $this->post(self::INITIATE_URI, $body);
        return $initiate_result;
    }

    function get_status(string $request_id): bool|stdClass
    {
        $shipping_status_response = $this->get(self::STATUS_URI . $request_id);
        return $shipping_status_response;
    }

    function cancel(array $order_ids): bool|array
    {
        $request = [];
        $request['idRefs'] = $order_ids;
        $shipping_status_response = $this->post(self::CANCEL_URI, $request);
        return $shipping_status_response;
    }

    function is_shipping_available(array $params): bool
    {
        $shipping_available_response = $this->get(self::AVAILABLE_URI, $params, self::DEFAULT_ACCEPT, 5);
        if (!$shipping_available_response) return false;
        return @$shipping_available_response->available;
    }
}
